@@ -239,7 +239,7 @@ class Request(object):
         step on each other. Use one or the other.
         """
         qu = cgi.parse_qs(self.uri.query)
-        query = {}
+        query = Jsdict()
         for key, value in qu.iteritems():
             if key.endswith('[]'):
                 if not isinstance(value, list):
